@@ -1,9 +1,7 @@
 # Standard Library
-import http
 from typing import Any, Dict, Iterable, Optional, Union
 
 # Django
-from django.forms import Form
 from django.http import HttpRequest, HttpResponse, StreamingHttpResponse
 from django.template.response import TemplateResponse
 
@@ -12,34 +10,6 @@ from .constants import TURBO_STREAM_MIME_TYPE, Action
 from .renderers import render_turbo_frame, render_turbo_stream
 
 
-class TemplateFormResponse(TemplateResponse):
-    """Automatically sets the correct response type to 422 if form contains errors.
-
-
-    .. deprecated :: 0.0.24
-        use :func:`turbo_response.shortcuts.render_form_response` instead.
-
-    """
-
-    def __init__(
-        self,
-        request: HttpRequest,
-        form: Form,
-        template: Union[str, Iterable[str]],
-        context: Optional[Dict[str, Any]] = None,
-        **kwargs,
-    ):
-        super().__init__(
-            request,
-            template,
-            context={"form": form, **(context or {})},
-            status=http.HTTPStatus.UNPROCESSABLE_ENTITY
-            if form.errors
-            else http.HTTPStatus.OK,
-            **kwargs,
-        )
-
-
 class TurboStreamResponseMixin:
     """Automatically sets the correct turbo-stream content type."""
 
@@ -99,7 +69,8 @@ class TurboStreamResponse(TurboStreamResponseMixin, HttpResponse):
 
     def __init__(self, content: str = "", *, action: Action, target: str, **kwargs):
         super().__init__(
-            render_turbo_stream(action, target, content), **kwargs,
+            render_turbo_stream(action, target, content),
+            **kwargs,
         )
 
 
@@ -154,7 +125,8 @@ class TurboFrameResponse(HttpResponse):
 
     def __init__(self, content: str = "", *, dom_id: str, **kwargs):
         super().__init__(
-            render_turbo_frame(dom_id, content), **kwargs,
+            render_turbo_frame(dom_id, content),
+            **kwargs,
         )
 
 
